@@ -253,56 +253,59 @@ var options = {};
 
 
 ###############
+## Thanks to Sebastian Kranz for this function
+## Thanks also to Wei Luo: http://theweiluo.wordpress.com/2011/09/30/r-to-json-for-d3-js-and-protovis
 
-toJSONarray <- function(dtf){
+# Transforms a vector into a vector of JSON strings that
+# can be pasted together afterwards
+toJsonSONvec <- function(vec) {
+  #restore.point("name.value")
+  na.row <- is.na(vec)
+  if(is(vec,'integer')){
+    ret <- vec
+  } else if (is(vec,'numeric')) {
+    # Round to 10 points after the decimal as before
+    ret <- as.character(signif(vec,digits=10))
+  } else if (is(vec,'logical')) {
+    ret <- tolower(as.character(vec))
+  } else if (is(vec,'Date')) {
+    y <- format(vec,"%Y")
+    m <- as.numeric(format(vec,"%m")) -1
+    d <- as.numeric(format(vec,"%d"))
+    ret <- paste("new Date(",y,",",m,",",d,")",sep="")
+  } else if (is(vec,'POSIXct') | is(vec,'POSIXlt')) {
+    y <- format(vec,"%Y")
+    m <- as.numeric(format(vec,"%m")) -1
+    d <- as.numeric(format(vec,"%d"))
+    H <- as.numeric(format(vec,"%H"))
+    M <- as.numeric(format(vec,"%M"))
+    S <- as.numeric(format(vec,"%S"))
+    ret <- paste("new Date(",y,",",m,",",d,",",H,",",M,",",S,")",sep="")
+  } else {
+    quote <- '"';
+    vec <- gsub('"', '\\\\"', vec)
+    ret <- paste(quote, vec, quote, sep='')
+  }
+  ret[na.row] <- "null"
+  ret
+}
+
+toJsonSONarray <- function(dtf){
   ## Thanks to Sebastian Kranz for this function
   ## Thanks also to Wei Luo: http://theweiluo.wordpress.com/2011/09/30/r-to-json-for-d3-js-and-protovis
   
-  #restore.point("toJSONarray")
+  #restore.point("toJsonSONarray")
   clnms <- colnames(dtf)
   
-  # Transforms a vector into a vector of JSON strings that
-  # can be pasted together afterwards
-  toJSONvec <- function(vec) {
-    #restore.point("name.value")
-    na.row <- is.na(vec)
-    if(is(vec,'integer')){
-      ret <- vec
-    } else if (is(vec,'numeric')) {
-      # Round to 10 points after the decimal as before
-      ret <- as.character(signif(vec,digits=10))
-    } else if (is(vec,'logical')) {
-      ret <- tolower(as.character(vec))
-    } else if (is(vec,'Date')) {
-      y <- format(vec,"%Y")
-      m <- as.numeric(format(vec,"%m")) -1
-      d <- as.numeric(format(vec,"%d"))
-      ret <- paste("new Date(",y,",",m,",",d,")",sep="")
-    } else if (is(vec,'POSIXct') | is(vec,'POSIXlt')) {
-      y <- format(vec,"%Y")
-      m <- as.numeric(format(vec,"%m")) -1
-      d <- as.numeric(format(vec,"%d"))
-      H <- as.numeric(format(vec,"%H"))
-      M <- as.numeric(format(vec,"%M"))
-      S <- as.numeric(format(vec,"%S"))
-      ret <- paste("new Date(",y,",",m,",",d,",",H,",",M,",",S,")",sep="")
-    } else {
-      quote <- '"';
-      vec <- gsub('"', '\\\\"', vec)
-      ret <- paste(quote, vec, quote, sep='')
-    }
-    ret[na.row] <- "null"
-    ret
-  }
   # Transform columns depending on data type and store in a list
-  objs <- lapply(dtf,toJSONvec)
+  objs <- lapply(dtf,toJsonSONvec)
   # Remove names just for the case that one column name was sep or collapse
   names(objs) <- NULL
   # Paste columns together
   str <- do.call(paste,c(objs,list(sep=",\n")))
   
   # Add [ ] and paste rows together
-  res <- paste('[\n ', paste("[\n",str,"\n]",collapse=',\n'), ' \n]',sep="")
+  res <- paste('[\n ', paste0("[\n",str,"\n]",collapse=',\n'), ' \n]',sep="")
   return(res)
 }
 
@@ -340,7 +343,7 @@ gvisFormat <- function(data){
   )
   
   ## The function is specified above
-  json <- toJSONarray(x.df)
+  json <- toJsonSONarray(x.df)
   output <- list(
     data.type = unlist(varTypes),
     json = json
@@ -524,23 +527,30 @@ gvisListener <- function(chartid, type, options=list(gvis=list(gvis.listener.jsc
 
 gvisOptions <- function(options=list(gvis=list(width = 600, height=500))){
   options <- options$gvis
+ 
   # wipe out options with start with gvis.
   options[grep("^gvis.",names(options))] <- NULL
+  #print(options)
   .par <- sapply(names(options), function(x){
     if(! (x %in% c("width", "height") & 
             ! is.numeric(type.convert(gsub("px","", options[[x]])))) 
-    ){
+  ){
+   
       paste("options[\"", x,"\"] = ",
             ifelse(any(checkSquareCurlBracketOps(options[[x]])),
                    paste(options[[x]], collapse="\n"),
-                 paste(toJSON(options[[x]], pretty=TRUE), collapse="\n")                                       
+                   #paste0( toJsonSONvec(options[[x]]), collapse="\n") 
+                   paste0( toJSON(unbox(options[[x]])), collapse="\n")  
             ),
             ";",sep="" )      
+      
+      
     }
   }
   )
-  .par <- .par[!sapply(.par,is.null)]
-  return(fixBackslash(.par))
+ .par <- .par[!sapply(.par,is.null)]
+ # print(.par)
+  return((.par))
 }
 
 
